==> react-native-wheel-picker-android-0.0.13.tgz: package/WheelPicker.js <==
'use strict';

import React, { Component, PropTypes } from 'react';
import { requireNativeComponent,View } from 'react-native';

var WheelPickerView = requireNativeComponent('WheelPicker', WheelPicker);
class WheelPicker extends React.Component {
  constructor(props) {
   super(props);
   this.onItemSelected = this.onItemSelected.bind(this);
 }
 onItemSelected(event: Event) {
   if (!this.props.onItemSelected) {
     return;
   }
   this.props.onItemSelected(event.nativeEvent);
  }

  render() {
     return (
       <WheelPickerView
         {...this.props}
         onChange={this.onItemSelected}
         data={this.props.data}
         isCurved={this.props.isCurved}
         isCyclic={this.props.isCyclic}
         isAtmospheric={this.props.isAtmospheric}
         selectedItemTextColor={this.props.selectedItemTextColor}
         itemSpace={this.props.itemSpace}
         visibleItemCount={this.props.visibleItemCount}
         renderIndicator={this.props.renderIndicator}
         indicatorColor={this.props.indicatorColor}
         isCurtain={this.props.isCurtain}
         curtainColor={this.props.curtainColor}
         itemTextColor={this.props.itemTextColor}
         itemTextSize={this.props.itemTextSize}
         selectedItemPosition={this.props.selectedItemPosition}
         backgroundColor={this.props.backgroundColor}
         />
     );
   }
}
WheelPicker.propTypes = {
  ...View.propTypes,
      onItemSelected: React.PropTypes.func,
      data: PropTypes.array,
      isCurved: PropTypes.bool,
      isCyclic: PropTypes.bool,
      isAtmospheric: PropTypes.bool,
      selectedItemTextColor: PropTypes.string,
      itemSpace: PropTypes.number,
      visibleItemCount: PropTypes.number,
      renderIndicator: PropTypes.bool,
      indicatorColor: PropTypes.string,
      isCurtain: PropTypes.bool,
      curtainColor: PropTypes.string,
      itemTextColor: PropTypes.string,
      itemTextSize: PropTypes.number,
      selectedItemPosition: PropTypes.number,
      backgroundColor: PropTypes.string,
};
module.exports = WheelPicker;

==> react-native-wheel-picker-android-1.0.1.tgz: package/WheelPicker.js <==
'use strict';

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { requireNativeComponent,View } from 'react-native';

var WheelPickerView = requireNativeComponent('WheelPicker', WheelPicker);
class WheelPicker extends React.Component {
  constructor(props) {
   super(props);
   this.onItemSelected = this.onItemSelected.bind(this);
   this.state = {
     selectedItemPosition: 0
   }
 }
 onItemSelected(event: Event) {
   if (!this.props.onItemSelected) {
     return;
   }
   this.props.onItemSelected(event.nativeEvent);
  }

  componentDidMount() {
     this.setState({ selectedItemPosition: this.props.selectedItemPosition })
   }

  render() {
     return (
       <WheelPickerView
         {...this.props}
         onChange={this.onItemSelected}
         data={this.props.data}
         isCurved={this.props.isCurved}
         isCyclic={this.props.isCyclic}
         isAtmospheric={this.props.isAtmospheric}
         selectedItemTextColor={this.props.selectedItemTextColor}
         itemSpace={this.props.itemSpace}
         visibleItemCount={this.props.visibleItemCount}
         renderIndicator={this.props.renderIndicator}
         indicatorColor={this.props.indicatorColor}
         isCurtain={this.props.isCurtain}
         curtainColor={this.props.curtainColor}
         itemTextColor={this.props.itemTextColor}
         itemTextSize={this.props.itemTextSize}
         itemTextFontFamily={this.props.itemTextFontFamily}
         selectedItemPosition={this.state.selectedItemPosition}
         backgroundColor={this.props.backgroundColor}
         />
     );
   }
}
WheelPicker.propTypes = {
  ...View.propTypes,
      onItemSelected: PropTypes.func,
      data: PropTypes.array,
      isCurved: PropTypes.bool,
      isCyclic: PropTypes.bool,
      isAtmospheric: PropTypes.bool,
      selectedItemTextColor: PropTypes.string,
      itemSpace: PropTypes.number,
      visibleItemCount: PropTypes.number,
      renderIndicator: PropTypes.bool,
      indicatorColor: PropTypes.string,
      isCurtain: PropTypes.bool,
      curtainColor: PropTypes.string,
      itemTextColor: PropTypes.string,
      itemTextSize: PropTypes.number,
      itemTextFontFamily: PropTypes.string,
      selectedItemPosition: PropTypes.number,
      backgroundColor: PropTypes.string,
};
module.exports = WheelPicker;
